==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_SEARCHRESULTS","Wyniki wyszukiwania");
define("_PAGE","Strona");
define("_RETURNTO","Powrt do");
define("_DEACTIVATE","Deaktywuj");
define("_ACTIVATE","Aktywuj");
define("_ENCYCLOPEDIA","Encyklopedia");
define("_NOCONTENTFORLETTER","Przepraszamy, nie ma adnej zawartoci dla tej litery");
define("_ENCYSELECTLETTER","Prosz wybra liter z poniszych:");
define("_COPYRIGHT","Prawa autorskie &copy; $sitename. Wszelkie Prawa Zastrzeone.");
define("_YOURADMINENCY","Jeste Administratorem, ta Encyklopedia nie jest aktywna!");
define("_ENCYNOTACTIVE","Przepraszamy, ta Encyklopedia nie jest teraz aktywna.");
define("_AVAILABLEENCYLIST","Lista dostpnych Encyklopedii w");
define("_YOURADMININACTIVELIST","Jeste Administratorem: oto lista nieaktywnych Encyklopedii:");
define("_NORESULTSTEXT","Brak wynikw w tekcie hase...");
define("_NORESULTSTITLE","Brak wynikw w nazwach hase...");
define("_SEARCHRESULTSFOR","Szukaj wynikw dla:");
define("_SEARCHNOTCOMPLETE","Opcje wyszukiwania nie s kompletne. Sprbuj ponownie.");
define("_RESULTSINTERMTITLE","Wyniki w tekcie opisu:");
define("_RESULTSINTERMTEXT","Wyniki w temacie opisu:");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Encyclopedia/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_SEARCHRESULTS","Wyniki wyszukiwania");
define("_PAGE","Strona");
define("_RETURNTO","Powrt do");
define("_DEACTIVATE","Deaktywuj");
define("_ACTIVATE","Aktywuj");
define("_ENCYCLOPEDIA","Encyklopedia");
define("_NOCONTENTFORLETTER","Przepraszamy, nie ma adnej zawartoci dla tej litery");
define("_ENCYSELECTLETTER","Prosz wybra liter z poniszych:");
define("_COPYRIGHT","Prawa autorskie &copy; $sitename. Wszelkie Prawa Zastrzeone.");
define("_YOURADMINENCY","Jeste Administratorem, ta Encyklopedia nie jest aktywna!");
define("_ENCYNOTACTIVE","Przepraszamy, ta Encyklopedia nie jest teraz aktywna.");
define("_AVAILABLEENCYLIST","Lista dostpnych Encyklopedii w");
define("_YOURADMININACTIVELIST","Jeste Administratorem: oto lista nieaktywnych Encyklopedii:");
define("_NORESULTSTEXT","Brak wynikw w tekcie hase...");
define("_NORESULTSTITLE","Brak wynikw w nazwach hase...");
define("_SEARCHRESULTSFOR","Szukaj wynikw dla:");
define("_SEARCHNOTCOMPLETE","Opcje wyszukiwania nie s kompletne. Sprbuj ponownie.");
define("_RESULTSINTERMTITLE","Wyniki w tekcie opisu:");
define("_RESULTSINTERMTEXT","Wyniki w temacie opisu:");

?>
